network\_wrangler.RoadwayNetwork
================================

.. currentmodule:: network_wrangler

.. autoclass:: RoadwayNetwork

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RoadwayNetwork.__init__
      ~RoadwayNetwork.add_new_roadway_feature_change
      ~RoadwayNetwork.addition_map
      ~RoadwayNetwork.apply
      ~RoadwayNetwork.apply_managed_lane_feature_change
      ~RoadwayNetwork.apply_roadway_feature_change
      ~RoadwayNetwork.assess_connectivity
      ~RoadwayNetwork.build_selection_key
      ~RoadwayNetwork.create_dummy_connector_links
      ~RoadwayNetwork.create_managed_lane_network
      ~RoadwayNetwork.delete_roadway_feature_change
      ~RoadwayNetwork.deletion_map
      ~RoadwayNetwork.get_managed_lane_node_ids
      ~RoadwayNetwork.get_modal_graph
      ~RoadwayNetwork.get_modal_links_nodes
      ~RoadwayNetwork.get_property_by_time_period_and_group
      ~RoadwayNetwork.is_network_connected
      ~RoadwayNetwork.network_connection_plot
      ~RoadwayNetwork.orig_dest_nodes_foreign_key
      ~RoadwayNetwork.ox_graph
      ~RoadwayNetwork.read
      ~RoadwayNetwork.roadway_net_to_gdf
      ~RoadwayNetwork.select_roadway_features
      ~RoadwayNetwork.selection_has_unique_link_id
      ~RoadwayNetwork.selection_map
      ~RoadwayNetwork.validate_link_schema
      ~RoadwayNetwork.validate_node_schema
      ~RoadwayNetwork.validate_object_types
      ~RoadwayNetwork.validate_properties
      ~RoadwayNetwork.validate_selection
      ~RoadwayNetwork.validate_shape_schema
      ~RoadwayNetwork.validate_uniqueness
      ~RoadwayNetwork.write
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RoadwayNetwork.CRS
      ~RoadwayNetwork.KEEP_SAME_ATTRIBUTES_ML_AND_GP
      ~RoadwayNetwork.LINK_FOREIGN_KEY
      ~RoadwayNetwork.MANAGED_LANES_LINK_ID_SCALAR
      ~RoadwayNetwork.MANAGED_LANES_NODE_ID_SCALAR
      ~RoadwayNetwork.MANAGED_LANES_REQUIRED_ATTRIBUTES
      ~RoadwayNetwork.MANAGED_LANES_SCALAR
      ~RoadwayNetwork.MAX_SEARCH_BREADTH
      ~RoadwayNetwork.MODES_TO_NETWORK_LINK_VARIABLES
      ~RoadwayNetwork.MODES_TO_NETWORK_NODE_VARIABLES
      ~RoadwayNetwork.NODE_FOREIGN_KEY
      ~RoadwayNetwork.SEARCH_BREADTH
      ~RoadwayNetwork.SELECTION_REQUIRES
      ~RoadwayNetwork.SP_WEIGHT_FACTOR
      ~RoadwayNetwork.UNIQUE_LINK_KEY
      ~RoadwayNetwork.UNIQUE_MODEL_LINK_IDENTIFIERS
      ~RoadwayNetwork.UNIQUE_NODE_IDENTIFIERS
      ~RoadwayNetwork.UNIQUE_NODE_KEY
      ~RoadwayNetwork.UNIQUE_SHAPE_KEY
   
   